!!! warning
    This page is under construction. The content may be incomplete or incorrect. Submit an issue
    on [GitHub](https://github.com/QuEraComputing/kirin/issues/new) if you need help or want to
    contribute.


# Cookbook

This cookbook provides a collection of quick examples to help you get started with Kirin. Each
example is a self-contained page that demonstrates a specific feature or use case. You can copy and
paste the code snippets into your own project and modify them as needed.

## Table of Contents

- [Continue of FoodLang](foodlang/cf_rewrite.md)
